# -*- encoding: utf-8 -*-

from django.db import models
from django.conf import settings
from models import Parent, PermissionMeta, Region, Pays

I_ETAT_CHOICES = ((0, "Jamais ouverte ou fermée"),
                  (1, "Active (budget + local + personnel + accès pour le public)"),
                  (2, "Ouverture imminente (budget + local en construction " + \
                          "ou personnel en cours de recrutement)"),
                  (3, "En projet (budget)"))

I_POSITION_CP_CHOICES = (("0", "à gauche"), ("1", "à droite"))

I_CONVENTION_CHOICES = (("2", "--"), ("0", "Non"), ("1", "Oui"))


class EmployeResponsable(Parent):
    __metaclass__ = PermissionMeta

    id = models.IntegerField (primary_key=True, db_column = 'no_employe')
    nom = models.CharField (max_length=128)
    prenom = models.CharField (max_length=128)
    sexe = models.CharField (max_length=1)
    id_implantation_1 = models.ForeignKey ('Implantation', blank=True,
            null=True, related_name='id_implantation_1',
            db_column='id_implantation_1')
    responsable_implantation_1 = models.IntegerField()
    poste_1_titre_poste_m = models.CharField (max_length=128)
    poste_1_titre_poste_f = models.CharField (max_length=128)
    complement_1 = models.CharField (max_length=128)
    id_implantation_2 = models.ForeignKey ('Implantation', blank=True,
            null=True, related_name='id_implantation_2',
            db_column='id_implantation_2')
    responsable_implantation_2 = models.IntegerField()
    poste_2_titre_poste_m = models.CharField (max_length=128)
    poste_2_titre_poste_f = models.CharField (max_length=128)
    complement_2 = models.CharField (max_length=128)

    def __unicode__ (self):
        string = ""
        if self.sexe == "m":
            string = "Monsieur %s %s, %s" % (self.prenom, self.nom, \
                    self.poste_1_titre_poste_m)
            if self.complement_1:
                string += " %s" % self.complement_1
            if self.poste_2_titre_poste_m:
                string += ", %s" % self.poste_2_titre_poste_m
                if self.complement_2:
                    string += " %s" % self.complement_2
        else:
            string = "Madame %s %s, %s" % (self.prenom, self.nom, \
                    self.poste_1_titre_poste_f)
            if self.complement_1:
                string += " %s" % self.complement_1
            if self.poste_2_titre_poste_f:
                string += ", %s" % self.poste_2_titre_poste_f
                if self.complement_2:
                    string += " %s" % self.complement_2
        return string

    class Meta:
        managed = False
        db_table = 'vue_employes_actifs_avec_dates_mandat'


class TypeImplantation(Parent):
    __metaclass__ = PermissionMeta

    id = models.SmallIntegerField(primary_key=True, db_column='id_type')
    nom = models.CharField(max_length=255, db_column='nom_type')
    abrev = models.CharField(max_length=3, db_column='abrev_type')
    def __unicode__ (self):
        return self.nom
    class Meta:
        db_table = u'type_implantations'
        ordering = ["nom",]

class Implantation(Parent):
    __metaclass__ = PermissionMeta

    id = models.AutoField(primary_key=True,
            db_column='id_implantation', editable=False)
    etat_implantation = models.SmallIntegerField(choices = I_ETAT_CHOICES,
            verbose_name = 'État de l\'implantation')
    commentaire_evolution_type = models.TextField(max_length=256, blank=True,
            null=True, verbose_name = 'Commentaire concernant l\'état de ' +
            'l\'implantation ou son évolution')
    nom_complet = models.CharField(max_length=256,
            verbose_name = 'Nom complet de l\'implantation')
    type = models.ForeignKey(TypeImplantation, db_column='id_type',
            verbose_name = 'Type d\'implantation')
    bureau_rattachement = models.ForeignKey('Implantation',
            db_column='bureau_rattachement',
            verbose_name = 'Bureau de rattachement', blank=True, null=True)
    region = models.ForeignKey(Region, db_column='id_region',
            verbose_name = 'Région de l\'AUF')
    adr_postale_precision_avant = models.CharField(max_length=256, blank=True,
            null=True, verbose_name = 'Précision avant l\'adresse')
    adr_postale_no_civique = models.CharField(max_length=10, blank=True,
            null=True, verbose_name = 'Numéro')
    adr_postale_rue = models.CharField(max_length=128, blank=True, null=True,
            verbose_name = 'Rue, avenue, boulevard, etc.')
    adr_postale_appart_suite_bureau = models.CharField(max_length=128,
            blank=True, null=True, verbose_name = 'Appartement, suite, bureau')
    adr_postale_precision = models.CharField(max_length=256, blank=True,
            null=True, verbose_name = 'Précision sur l\'adresse postale')
    adr_postale_boite_postale = models.CharField(max_length=50, blank=True,
            null=True, verbose_name = 'Boîte postale')
    adr_postale_ville = models.CharField(max_length=60, verbose_name = 'Ville')
    adr_postale_code_postal = models.CharField(max_length=10, blank=True,
            null=True, verbose_name = 'Code postal')
    adr_postale_position_cp = models.CharField(max_length=1,
            choices=I_POSITION_CP_CHOICES, default="0",
            verbose_name = 'Position du code postal par rapport a la ville')
    adr_postale_region_prov_etat = models.CharField(max_length=60, blank=True,
            null=True, verbose_name = 'Province')
    adr_postale_pays = models.ForeignKey(Pays, related_name='adr_postale_pays',
            db_column='adr_postale_pays', verbose_name = 'Pays')
    adr_physique_precision_avant = models.CharField(max_length=256, blank=True,
            null=True, verbose_name = 'Précision avant l\'adresse')
    adr_physique_no_civique = models.CharField(max_length=10, blank=True,
            null=True, verbose_name = 'Numéro')
    adr_physique_rue = models.CharField(max_length=128, blank=True, null=True,
            verbose_name = 'Rue, avenue, boulevard, etc.')
    adr_physique_appart_suite_bureau = models.CharField(max_length=128,
            blank=True, null=True, verbose_name = 'Appartement, suite, bureau')
    adr_physique_precision = models.CharField(max_length=256, blank=True,
            null=True, verbose_name = 'Précision sur l\'adresse physique')
    adr_physique_ville = models.CharField(max_length=60, blank=True, null=True,
            verbose_name = 'Ville')
    adr_physique_code_postal = models.CharField(max_length=10, blank=True,
            null=True, verbose_name = 'Code postal')
    adr_physique_position_cp = models.CharField(max_length=1,
            choices=I_POSITION_CP_CHOICES, default="0",
            verbose_name = 'Position du code postal par rapport a la ville')
    adr_physique_region_prov_etat = models.CharField(max_length=60, blank=True,
            null=True, verbose_name = 'Province')
    adr_physique_pays = models.ForeignKey(Pays, related_name='adr_physique_pays',
            db_column='adr_physique_pays', verbose_name = 'Pays')
    telephone_publique = models.CharField(max_length=20, blank=True, null=True,
            verbose_name = 'Téléphone (pour diffusion publique)')
    telephone_interne = models.CharField(max_length=20, blank=True, null=True,
            verbose_name = 'Téléphone (pour diffusion interne seulement)')
    fax_publique = models.CharField(max_length=20, blank=True, null=True,
            verbose_name = 'Télécopieur (pour diffusion publique)')
    fax_interne = models.CharField(max_length=20, blank=True, null=True,
            verbose_name = 'Télécopieur (pour diffusion interne seulement)')
    courriel_publique = models.CharField(max_length=64, blank=True, null=True,
            verbose_name = 'Courriel (pour diffusion publique)')
    courriel_interne = models.CharField(max_length=64, blank=True, null=True,
            verbose_name = 'Courriel (pour diffusion interne seulement)')
    url = models.CharField(max_length=64, blank=True, null=True,
            verbose_name = 'Adresse du site Web')
    date_ouverture = models.CharField(max_length=10, blank=True, null=True,
            verbose_name = 'Date d\'ouverture')
    date_inauguration = models.CharField(max_length=10, blank=True, null=True,
            verbose_name = 'Date d\'inauguration')
    date_extension = models.CharField(max_length=10, blank=True, null=True,
            verbose_name = 'Date d\'extension')
    date_fermeture = models.CharField(max_length=10, blank=True, null=True,
            verbose_name = 'Date de fermeture')
    date_derniere_modif = models.CharField(max_length=10, blank=True,
            null=True, verbose_name = 'Derniere mise a jour')
    hebergement_etablissement = models.CharField(max_length=256, blank=True,
            null=True, verbose_name = 'Établissement d\'hébergement')
    hebergement_convention = models.CharField(max_length = 1, default="0",
            choices=I_CONVENTION_CHOICES,
            verbose_name = 'Convention d\'hébergement de l\'implantation')
    accord_siege = models.TextField(blank=True, null=True)
    date_hebergement_convention = models.CharField(max_length=10, blank=True,
            null=True, verbose_name = 'Date de la convention d\'hébergement')
    fuseau_horaire = models.CharField(max_length=4, blank=True, null=True,
            verbose_name = 'Fuseau horaire')
    code_meteo = models.CharField(max_length=10, blank=True, null=True,
            verbose_name = 'Code météo')
    remarques = models.TextField(max_length=512, blank=True, null=True,
            verbose_name = 'Remarques')
    nom_long = models.CharField(max_length=36,
            verbose_name = 'Nom long de l\'implantation')
    nom_court = models.CharField(max_length=20,
            verbose_name = 'Nom court de l\'implantation')
    latitude = models.FloatField (null=True, blank=True)
    longitude = models.FloatField (null=True, blank=True)

    def __unicode__ (self):
        return self.nom_complet

    class Meta:
        db_table = u'implantations'
        ordering = ['nom_complet']
