# -*- encoding: utf-8 -*-
from django.db import models
from django.db.models.base import ModelBase
from django.conf import settings
from django_roa.db.models import ROAModelBase
from django_roa import Model as ROAModel



class _PermissionMeta(ModelBase):
    def __new__(cls, name, bases, attrs):
        klas = super(_PermissionMeta, cls).__new__(cls, name, bases, attrs)
        klas._meta.permissions.append(('list_' + klas._meta.module_name, 
                                       u'Can list %s' % klas._meta.verbose_name))
        return klas

if getattr(settings, 'ROA_MODELS', False):
    class PermissionMeta(_PermissionMeta, ROAModelBase):
        pass
    class Parent(ROAModel):
        class Meta:
            abstract = True
else:
    class PermissionMeta(_PermissionMeta):
        pass
    class Parent(models.Model):
        class Meta:
            abstract = True

class Pays(Parent):
    __metaclass__ = PermissionMeta

    code_iso2 = models.TextField(primary_key=True)
    code_iso3 = models.TextField()
    intitule = models.CharField(max_length=128)
    fiche = models.SmallIntegerField()
    code_bureau = models.CharField(max_length=12)
    accord_siege = models.SmallIntegerField()
    date_accord_siege = models.CharField(max_length=128)
    info = models.CharField(max_length=255)
    info_securisee = models.SmallIntegerField()
    nom_territoire = models.CharField(max_length=128)
    nord_sud = models.CharField(max_length=12)
    region_monde = models.CharField(max_length=64)
    nom_officiel = models.CharField(max_length=255)
    langue_officiel = models.CharField(max_length=255)
    voisins = models.CharField(max_length=255)
    superficie = models.CharField(max_length=20)
    population = models.CharField(max_length=20)
    densite = models.CharField(max_length=20)
    capitale = models.CharField(max_length=64)
    population_capitale = models.CharField(max_length=20)
    principales_villes = models.CharField(max_length=255)
    point_culminant = models.CharField(max_length=20)
    fetes = models.CharField(max_length=255)
    devise = models.CharField(max_length=64)
    monnaie = models.CharField(max_length=64)
    indicatif_telephonique = models.IntegerField()
    standard_electrique = models.CharField(max_length=32)
    heure_hiver = models.TextField()
    heure_ete = models.TextField()
    date_heure_ete = models.CharField(max_length=20)
    lien_officiel = models.CharField(max_length=255)
    date_onu = models.CharField(max_length=10)
    developpement = models.CharField(max_length=255)
    nationalite = models.CharField(max_length=32)
    intitule_publication = models.CharField(max_length=128)

    def __unicode__ (self):
        return self.intitule

    class Meta:
        db_table = u'ref_pays'
        ordering = ["intitule"]
        #managed = False

class Region(Parent):
    __metaclass__ = PermissionMeta

    id_region = models.SmallIntegerField(primary_key=True)
    nom_region = models.CharField(max_length=255)
    abrev_region = models.CharField(max_length=3)
    id_bureau = models.SmallIntegerField()

    def __unicode__ (self):
        return self.nom_region

    class Meta:
        db_table = u'regions'
        ordering = ["nom_region"]
        #managed = False

class AufUser (Parent):
    __metaclass__ = PermissionMeta

    email = models.CharField (primary_key=True, max_length=60, db_column='courriel')
    password = models.CharField (max_length=35, db_column='motdepasse')
    first_name = models.CharField (max_length=50, db_column='prenom')
    last_name = models.CharField (max_length=50, db_column='nom')
    class Meta:
        db_table = 'utilisateurs'
        #managed = False
